@@ -13,14 +13,14 @@
 #ifndef OPENSHOT_VERSION_H
 #define OPENSHOT_VERSION_H
 
-#define OPENSHOT_VERSION_ALL "0.4.0"        /// A string of the entire version "Major.Minor.Build"
-#define OPENSHOT_VERSION_FULL "0.4.0"   /// A string of the full version identifier, including suffixes (e.g. "0.0.0-dev0")
-#define OPENSHOT_VERSION_MAJOR_MINOR "0.4"  /// A string of the "Major.Minor" version
+#define OPENSHOT_VERSION_ALL "0.5.0"        /// A string of the entire version "Major.Minor.Build"
+#define OPENSHOT_VERSION_FULL "0.5.0"   /// A string of the full version identifier, including suffixes (e.g. "0.0.0-dev0")
+#define OPENSHOT_VERSION_MAJOR_MINOR "0.5"  /// A string of the "Major.Minor" version
 
 #define OPENSHOT_VERSION_MAJOR 0   /// Major version number is incremented when huge features are added or improved.
-#define OPENSHOT_VERSION_MINOR 4   /// Minor version is incremented when smaller (but still very important) improvements are added.
+#define OPENSHOT_VERSION_MINOR 5   /// Minor version is incremented when smaller (but still very important) improvements are added.
 #define OPENSHOT_VERSION_BUILD 0   /// Build number is incremented when minor bug fixes and less important improvements are added.
-#define OPENSHOT_VERSION_SO 27         /// Shared object version number. This increments any time the API and ABI changes (so old apps will no longer link)
+#define OPENSHOT_VERSION_SO 28         /// Shared object version number. This increments any time the API and ABI changes (so old apps will no longer link)
 
 // Useful dependency versioning / feature availability
 #define QT_VERSION_STR "5.15.18"
@@ -35,7 +35,7 @@
 #define FFMPEG_USE_SWRESAMPLE 1
 #define APPIMAGE_BUILD 0
 
-#include <sstream>
+#include <string>
 
 namespace openshot
 {
@@ -47,10 +47,8 @@ namespace openshot
 		static const int So = OPENSHOT_VERSION_SO; /// Shared Object Number (incremented when API or ABI changes)
 
 		/// Get a string version of the version (i.e. "Major.Minor.Build")
-		inline static const std::string ToString() {
-			std::stringstream version_string;
-			version_string << Major << "." << Minor << "." << Build;
-			return version_string.str();
+		inline static std::string ToString() {
+			return std::to_string(Major) + "." + std::to_string(Minor) + "." + std::to_string(Build);
 		}
 	};
 
